@@ -26,11 +26,11 @@ and any other relevant data.
 
 =head1 VERSION
 
-Version 0.012
+Version 0.013
 
 =cut
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 my $tools = {
     unix => {
@@ -46,8 +46,10 @@ my $tools = {
 =head1 SYNOPSIS
 
     use Net::Hacky::Detect::IP;
-
-    my @ips = Net::Hacky::Detect::IP->scan();
+    my @ips = @{ Net::Hacky::Detect::IP->scan() };
+    foreach my $ip (@ips) {
+        print "Detected ip: $ip\n";
+    }
 
 =head1 DESCRIPTION 
 
